Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(260)

Unified Diff: src/x64/lithium-codegen-x64.cc

Issue 6312122: Don't use eax on x64. :) (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Fix patch? Created 9 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/x64/lithium-codegen-x64.cc
diff --git a/src/x64/lithium-codegen-x64.cc b/src/x64/lithium-codegen-x64.cc
index 12d912c396f1a146b1326628f20dbbd91d90681b..0bf218d864ff2872d368c865b8a30e2c4eecd329 100644
--- a/src/x64/lithium-codegen-x64.cc
+++ b/src/x64/lithium-codegen-x64.cc
@@ -1529,7 +1529,7 @@ void LCodeGen::CallKnownFunction(Handle<JSFunction> function,
__ movq(rsi, FieldOperand(rdi, JSFunction::kContextOffset));
}
// Set eax to arguments count if adaption is not needed. Assumes that eax
// is available to write to at this point.
if (!function->NeedsArgumentsAdaption()) {
__ Set(rax, arity);
@@ -1554,7 +1554,7 @@ void LCodeGen::CallKnownFunction(Handle<JSFunction> function,
void LCodeGen::DoCallConstantFunction(LCallConstantFunction* instr) {
- ASSERT(ToRegister(instr->result()).is(eax));
+ ASSERT(ToRegister(instr->result()).is(rax));
__ Move(rdi, instr->function());
CallKnownFunction(instr->function(), instr->arity(), instr);
}
@@ -1529,7 +1529,7 @@ void LCodeGen::CallKnownFunction(Handle<JSFunction> function,
__ movq(rsi, FieldOperand(rdi, JSFunction::kContextOffset));
}
- // Set eax to arguments count if adaption is not needed. Assumes that eax
+ // Set rax to arguments count if adaption is not needed. Assumes that rax
// is available to write to at this point.
if (!function->NeedsArgumentsAdaption()) {
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698